# Prerequisite
Conda

# Installation

## Install from source
```
git clone https://github.com/inisis/caffe.git
pip install .
```

## Install from pypi
```
pip install brocolli-caffe
```

# How to use
```
python -c "import caffe; print(caffe.__version__)"
```